pygeodesy.geodesicx.gx.GeodesicLineExact

Package pygeodesy :: Package geodesicx :: Module gx :: Class GeodesicLineExact |
[frames] | no frames]

# Class GeodesicLineExact

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
        karney._CapsBase --+
                           |
       gxbases._GeodesicBase --+
                               |
       gxline._GeodesicLineExact --+
                                   |
                                  GeodesicLineExact

A pure Python version of Karney's C++ class GeodesicLineExact, modeled after Karney's Python class geodesicline.GeodesicLine.

Instance Methods
__init__(self, geodesic, lat1, lon1, azi1, caps=1929, **name) New GeodesicLineExact instance, allowing points to be found along a geodesic starting at `(lat1, lon1)` with azimuth `azi1`. |
Inherited from `gxline._GeodesicLineExact`: `Arc`, `ArcPosition`, `Distance`, `Intersecant2`, `PlumbTo`, `Position`, `SetArc`, `SetDistance`, `__del__`, `toStr` Inherited from `karney._CapsBase`: `caps_` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables
Inherited from `karney._CapsBase`: `ALL`, `AREA`, `AZIMUTH`, `DISTANCE`, `DISTANCE_IN`, `EMPTY`, `GEODESICSCALE`, `LATITUDE`, `LINE_CAPS`, `LINE_OFF`, `LONGITUDE`, `LONG_UNROLL`, `NONFINITONAN`, `REDUCEDLENGTH`, `STANDARD`, `STANDARD_LINE`

Properties
Inherited from `gxline._GeodesicLineExact`: `a1`, `a13`, `azi0`, `azi0_sincos2`, `azi1`, `azi1_sincos2`, `equatorarc`, `equatorazimuth`, `geodesic`, `lat1`, `lon1`, `s13` Inherited from `karney._CapsBase`: `caps`, `debug` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, geodesic, lat1, lon1, azi1, caps=1929, **name) (Constructor) |
New GeodesicLineExact instance, allowing points to be found along a geodesic starting at `(lat1, lon1)` with azimuth `azi1`. Arguments: `geodesic` - The geodesic to use (GeodesicExact). `lat1` - Latitude of the first point (`degrees`). `lon1` - Longitude of the first point (`degrees`). `azi1` - Azimuth at the first points (compass `degrees`). `caps` - Bit-or'ed combination of Caps values specifying the capabilities the GeodesicLineExact instance should possess, i.e., which quantities can bereturned by methods GeodesicLineExact.Position and GeodesicLineExact.ArcPosition. `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `geodesic`. Overrides: object.__init__